.TH sane-gt68xx 5 "25 Oct 2002"
.IX sane-gt68xx
.SH NAME
sane-gt68xx - SANE backend for GT-68XX based USB flatbed scanners
.SH DESCRIPTION
The
.B sane-gt68xx
library implements a SANE (Scanner Access Now Easy) backend that provides
access to USB flatbed scanners based on the Grandtech GT-6801 and GT-6816
chips.  At present, the following scanners are known to work with this
backend:
.PP
.RS
Artec Ultima 2000 (only product 0x4002)
.br
Boeder SmartScan Slim Edition
.br
Lexmark X70
.br
Medion/Lifetec/Tevion/Cytron MD/LT 9385
.br
Medion/Lifetec/Tevion LT 9452
.br
Medion/Lifetec/Tevion MD 9458
.br
Mustek BearPaw 1200 CS
.br
Mustek BearPaw 1200 CU
.br
Mustek BearPaw 1200 TA
.br
Mustek BearPaw 2400 CU (Plus)
.br
Mustek BearPaw 2400 TA (Plus)
.br
Mustek ScanExpress 1200 UB Plus
.br
Packard Bell Diamond 1200
.br
Trust Compact Scan USB 19200
.br
Trust Flat Scan USB 19200
.RE
.PP
More details can be found on the gt68xx backend homepage 
.IR http://www.meier-geinitz.de/sane/gt68xx/ .
.PP
This is ALPHA software. Keep your hand at the scanner's plug and unplug it, if
the head bumps at the end of the scan area.
.PP
If you own a scanner other than the ones listed above that works with this
backend, please let me know this by sending the scanner's exact model name and
the USB vendor and device ids (e.g. from /proc/bus/usb/devices,
sane-find-scanner or syslog) to me. Even if the scanner's name is only
slightly different from the models mentioned above, please let me know.
.PP
.SH KERNEL ISSUES
If libusb-0.1.6 or later is installed, this section can be skipped. The
scanner should be found by sane-find-scanner without further actions. For
setting permissions and general USB information looks at sane-usb(5).
.PP
The scanners based on the GT-6816 (Mustek BearPaw TA and BearPaw Plus models,
the Packard Bell and the Lexmark scanner) need a Linux kernel 2.4.12 or newer.
Recent 2.2 kernels may also work, but I haven't tested them.
.PP
The scanners based on the GT-6801 (all other scanners) need an updated kernel
scanner module that is not yet included in the official kernel code. It can
be downloaded from the gt68xx backend homepage. There is also an installation
instruction.

.SH FIRMWARE FILE
You need a firmware file for your scanner. That's a small file containing
software that will be uploaded to the scanner's memory. It's usually named
*.usb, e.g. PS1fw.usb. It comes on the installation CD that was provided by
the manufacturer, but it may be packaged together with the installation
program in an .exe file. For Mustek scanners, the file can be dowloaded from
the gt68xx backend homepage. For other scanners, check the CD for .usb
files. If everything else fails, you must install the Windows driver and get
the firmware from there (usually in the windows/system or system32
directories). Put that firmware file into @DATADIR@/sane/gt68xx/.
.SH CONFIGURATION
The contents of the
.I gt68xx.conf
file is a list of usb lines containing vendor and product ids that correspond
to USB scanners. The file can also contain option lines.  Empty lines and
lines starting with a hash mark (#) are ignored.  The scanners are
autodetected by
.I usb vendor_id product_id
statements which are already included into
.IR gt68xx.conf .
"vendor_id" and "product_id" are hexadecimal numbers that identfy the
scanner. 
.PP
The 
.IR override ,
.IR firmware ,
.IR vendor ,
and
.I model
options must be placed after the
.I usb
line they refer to.
.PP
Option
.I override
is used to override the default model parameters. That's necessary for some
scanners that use the same vendor/product ids but are different. For these
scanners there are already commented out override lines in the configuration
file. 
.I override "mustek-scanexpress-1200-ub-plus"
is necessary for the Mustek Scanexpress 1200 UB Plus, the
Medion/Lifetec/Tevion LT 9452, and the Trust Compact Scan USB 19200.
.I override "artec-ultima-2000"
is used for the Artec Ultima 2000, the Boeder SmartScan Slim Edition, the
Medion/ Lifetec/ Tevion/ Cytron MD/LT 9385, the Medion/ Lifetec/ Tevion MD
9458, and the Trust Flat Scan USB 19200.
.I override "mustek-bearpaw-2400-cu"
is necessary for the Mustek BearPaw 2400 CU.
.PP
Option
.I firmware
selects the name and path of the firmware file. It's only necessary if the
default (or override) doesn't work. The default firmware directory is
@DATADIR@/sane/gt68xx/. You may need to create this directory. If you
want to place the firmware files at a different path, use a 
.I firmware
line.
.PP
The 
.I vendor
and
.I model
options are not absolutely necessary but for convenience. Quite a lot of
scanners from different manufacturers share the same vendor/product ids so you
can set the "correct" name here.
.PP
A sample configuration file is shown below:
.PP
.RS
usb 0x05d8 0x4002
.br
override "mustek-scanexpress-1200-ub-plus"
.br
firmware "/opt/gt68xx/SBfw.usb"
.br
vendor "Trust"
.br
product "Compact Scan USB 19200"
.RE


.SH FILES
.TP
.I @CONFIGDIR@/gt68xx.conf
The backend configuration file (see also description of
.B SANE_CONFIG_DIR
below).
.TP
.I @LIBDIR@/libsane-gt68xx.a
The static library implementing this backend.
.TP
.I @LIBDIR@/libsane-gt68xx.so
The shared library implementing this backend (present on systems that
support dynamic loading).
.SH ENVIRONMENT
.TP
.B SANE_CONFIG_DIR
This environment variable specifies the list of directories that may
contain the configuration file.  Under UNIX, the directories are
separated by a colon (`:'), under OS/2, they are separated by a
semi-colon (`;').  If this variable is not set, the configuration file
is searched in two default directories: first, the current working
directory (".") and then in @CONFIGDIR@.  If the value of the
environment variable ends with the directory separator character, then
the default directories are searched after the explicitly specified
directories.  For example, setting
.B SANE_CONFIG_DIR
to "/tmp/config:" would result in directories "tmp/config", ".", and
"@CONFIGDIR@" being searched (in this order).
.TP
.B SANE_DEBUG_GT68XX
If the library was compiled with debug support enabled, this
environment variable controls the debug level for this backend.  Higher
debug levels increase the verbosity of the output. 

Example: 
export SANE_DEBUG_GT68XX=4

.SH "SEE ALSO"
sane(7), sane-usb(5)
.br
@DOCDIR@/gt68xx/gt68xx.CHANGES
 
.SH AUTHOR
Henning Meier-Geinitz <henning@meier-geinitz.de>
.br
The original gt68xx driver was written by Sergey Vlasov, Andreas Nowack, and
David Stevenson. Thanks for sending patches and answering questions to them
and all the other contributors.
.SH BUGS
Currently scanning seems to only work under Linux. With the BSDs, either the
first command after the firmware boot or the reading of the scanned data times
out.
.PP
Automatic gain is slow (especially 2400 CU). Maybe use the existing default
values. Also, default values could be added to gt68xx.conf. Check if auto-gain
for CCD scanners should use the max/min values, too.
.PP
The first few lines of the image are garbage for the 2400 TA
Plus.
.PP
The images are too dark for some scanners, especially in TA mode. Maybe
add a gamma option?
.PP
Interpolation should be used instead of just copying data, when the X- and
Y-resolution differ.
.PP
Support for buttons is missing.
.PP
More detailed bug information is
available at the gt68xx backend homepage
.IR http://www.meier-geinitz.de/sane/gt68xx .
Please contact me if you find a bug or missing feature:
<henning@meier-geinitz.de>
